@@ -99,6 +99,7 @@ from dagster.core.definitions import (
     TableSchema,
     TableSchemaMetadataValue,
     TextMetadataValue,
+    TimeWindowPartitionsDefinition,
     TypeCheck,
     UrlMetadataValue,
     WeeklyPartitionsDefinition,
@@ -573,6 +574,7 @@ __all__ = [
     "DailyPartitionsDefinition",
     "HourlyPartitionsDefinition",
     "MonthlyPartitionsDefinition",
+    "TimeWindowPartitionsDefinition",
     "WeeklyPartitionsDefinition",
     "Partition",
     "PartitionedConfig",
