@@ -3,6 +3,7 @@ import os
 import pkgutil
 import re
 import warnings
+from collections import defaultdict
 from importlib import import_module
 from types import ModuleType
 from typing import (
@@ -22,6 +23,9 @@ from typing import (
 
 from dagster import check
 from dagster.core.definitions.events import AssetKey
+from dagster.core.definitions.executor_definition import in_process_executor
+from dagster.core.errors import DagsterUnmetExecutorRequirementsError
+from dagster.core.execution.execute_in_process_result import ExecuteInProcessResult
 from dagster.core.storage.fs_asset_io_manager import fs_asset_io_manager
 from dagster.utils import merge_dicts
 from dagster.utils.backcompat import ExperimentalWarning
@@ -29,12 +33,15 @@ from dagster.utils.backcompat import ExperimentalWarning
 from ..definitions.executor_definition import ExecutorDefinition
 from ..definitions.job_definition import JobDefinition
 from ..definitions.op_definition import OpDefinition
+from ..definitions.partition import PartitionsDefinition
 from ..definitions.resource_definition import ResourceDefinition
 from ..errors import DagsterInvalidDefinitionError
 from .assets import AssetsDefinition
 from .assets_job import build_assets_job, build_root_manager, build_source_assets_by_key
 from .source_asset import SourceAsset
 
+ASSET_GROUP_BASE_JOB_PREFIX = "__ASSET_GROUP"
+
 
 class AssetGroup(
     NamedTuple(
@@ -148,9 +155,8 @@ class AssetGroup(
         )
 
     @staticmethod
-    def all_assets_job_name() -> str:
-        """The name of the mega-job that the provided list of assets is coerced into."""
-        return "__ASSET_GROUP"
+    def is_base_job_name(name) -> bool:
+        return name.startswith(ASSET_GROUP_BASE_JOB_PREFIX)
 
     def build_job(
         self,
@@ -475,6 +481,82 @@ class AssetGroup(
             check.failed("Could not find a module for the caller")
         return AssetGroup.from_modules([module], resource_defs, executor_def)
 
+    def materialize(
+        self, selection: Optional[Union[str, List[str]]] = None
+    ) -> ExecuteInProcessResult:
+        """
+        Executes an in-process run that materializes all assets in the group.
+
+        The execution proceeds serially, in a single thread. Only supported by AssetGroups that have
+        no executor_def or that that use the in-process executor.
+
+        Args:
+            selection (Union[str, List[str]]): A single selection query or list of selection queries
+                to for assets in the group. For example:
+
+                    - ``['some_asset_key']`` select ``some_asset_key`` itself.
+                    - ``['*some_asset_key']`` select ``some_asset_key`` and all its ancestors (upstream dependencies).
+                    - ``['*some_asset_key+++']`` select ``some_asset_key``, all its ancestors, and its descendants (downstream dependencies) within 3 levels down.
+                    - ``['*some_asset_key', 'other_asset_key_a', 'other_asset_key_b+']`` select ``some_asset_key`` and all its ancestors, ``other_asset_key_a`` itself, and ``other_asset_key_b`` and its direct child asset keys. When subselecting into a multi-asset, all of the asset keys in that multi-asset must be selected.
+
+        Returns:
+            ExecuteInProcessResult: The result of the execution.
+        """
+        if self.executor_def and self.executor_def is not in_process_executor:
+            raise DagsterUnmetExecutorRequirementsError(
+                "'materialize' can only be invoked on AssetGroups which have no executor or have "
+                "the in_process_executor, but the AssetGroup had executor "
+                f"'{self.executor_def.name}'"
+            )
+
+        return self.build_job(
+            name="in_process_materialization_job", selection=selection
+        ).execute_in_process()
+
+    def get_base_jobs(self) -> Sequence[JobDefinition]:
+        """For internal use only."""
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore", category=ExperimentalWarning)
+
+            assets_by_partitions_def: Dict[
+                Optional[PartitionsDefinition], List[AssetsDefinition]
+            ] = defaultdict(list)
+            for assets_def in self.assets:
+                assets_by_partitions_def[assets_def.partitions_def].append(assets_def)
+
+            if len(assets_by_partitions_def.keys()) == 0 or assets_by_partitions_def.keys() == {
+                None
+            }:
+                return [
+                    build_assets_job(
+                        ASSET_GROUP_BASE_JOB_PREFIX,
+                        assets=self.assets,
+                        source_assets=self.source_assets,
+                        resource_defs=self.resource_defs,
+                        executor_def=self.executor_def,
+                    )
+                ]
+            else:
+                unpartitioned_assets = assets_by_partitions_def.get(None, [])
+                jobs = []
+
+                # sort to ensure some stability in the ordering
+                for i, (partitions_def, assets_with_partitions) in enumerate(
+                    sorted(assets_by_partitions_def.items(), key=lambda item: repr(item[0]))
+                ):
+                    if partitions_def is not None:
+                        jobs.append(
+                            build_assets_job(
+                                f"{ASSET_GROUP_BASE_JOB_PREFIX}_{i}",
+                                assets=assets_with_partitions + unpartitioned_assets,
+                                source_assets=[*self.source_assets, *self.assets],
+                                resource_defs=self.resource_defs,
+                                executor_def=self.executor_def,
+                            )
+                        )
+
+                return jobs
+
 
 def _find_assets_in_module(
     module: ModuleType,
