@@ -1,6 +1,17 @@
 import itertools
 import warnings
-from typing import AbstractSet, Any, Dict, Mapping, Optional, Sequence, Tuple, Union, cast
+from typing import (
+    AbstractSet,
+    Any,
+    Dict,
+    Mapping,
+    NamedTuple,
+    Optional,
+    Sequence,
+    Tuple,
+    Union,
+    cast,
+)
 
 from dagster import check
 from dagster.core.definitions.config import ConfigMapping
@@ -254,9 +265,18 @@ def build_root_manager(
                 def _op():
                     pass
 
-            resource_config = input_context.step_context.resolved_run_config.resources[
+            step_context = input_context.step_context
+            resource_config = step_context.resolved_run_config.resources[
                 source_asset.io_manager_key
             ].config
+            io_manager_def = (
+                step_context.pipeline.get_definition()
+                .mode_definitions[0]
+                .resource_defs[source_asset.io_manager_key]
+            )
+            resources = step_context.scoped_resources_builder.build(
+                io_manager_def.required_resource_keys
+            )
 
             output_context = build_output_context(
                 name=source_asset_key.path[-1],
@@ -264,6 +284,7 @@ def build_root_manager(
                 solid_def=_op,
                 metadata=cast(Dict[str, Any], source_asset.metadata),
                 resource_config=resource_config,
+                resources=cast(NamedTuple, resources)._asdict(),
             )
             input_context_with_upstream = build_input_context(
                 name=input_context.name,
@@ -274,6 +295,7 @@ def build_root_manager(
                 op_def=input_context.op_def,
                 step_context=input_context.step_context,
                 resource_config=resource_config,
+                resources=cast(NamedTuple, resources)._asdict(),
             )
 
             io_manager = getattr(cast(Any, input_context.resources), source_asset.io_manager_key)
