@@ -605,6 +605,7 @@ class PendingNodeInvocation:
         instance: Optional["DagsterInstance"] = None,
         resources: Optional[Dict[str, Any]] = None,
         raise_on_error: bool = True,
+        run_id: Optional[str] = None,
     ) -> "ExecuteInProcessResult":
         if not isinstance(self.node_def, GraphDefinition):
             raise DagsterInvalidInvocationError(
@@ -617,7 +618,6 @@ class PendingNodeInvocation:
 
         from .executor_definition import execute_in_process_executor
         from .job_definition import JobDefinition
-        from .mode import ModeDefinition
 
         if len(self.node_def.input_defs) > 0:
             raise DagsterInvariantViolationError(
@@ -627,10 +627,8 @@ class PendingNodeInvocation:
         ephemeral_job = JobDefinition(
             name=self.given_alias,
             graph_def=self.node_def,
-            mode_def=ModeDefinition(
-                executor_defs=[execute_in_process_executor],
-                resource_defs=wrap_resources_for_execution(resources),
-            ),
+            executor_def=execute_in_process_executor,
+            resource_defs=wrap_resources_for_execution(resources),
             tags=self.tags,
             hook_defs=self.hook_defs,
             op_retry_policy=self.retry_policy,
@@ -643,6 +641,7 @@ class PendingNodeInvocation:
             instance=instance,
             output_capturing_enabled=True,
             raise_on_error=raise_on_error,
+            run_id=run_id,
         )
 
 
