@@ -388,7 +388,7 @@ class Out(
 
     def __new__(
         cls,
-        dagster_type: Union[Type, DagsterType, Type[NoValueSentinel]] = NoValueSentinel,
+        dagster_type: Union[Type, DagsterType] = NoValueSentinel,
         description: Optional[str] = None,
         is_required: bool = True,
         io_manager_key: Optional[str] = None,
@@ -401,7 +401,7 @@ class Out(
         # make sure new parameters are updated in combine_with_inferred below
     ):
         if asset_partitions_def:
-            experimental_arg_warning("assets_definition", "Out.__new__")
+            experimental_arg_warning("asset_partitions_definition", "Out.__new__")
         return super(Out, cls).__new__(
             cls,
             dagster_type=NoValueSentinel
