@@ -1,11 +1,13 @@
 import copy
 from contextlib import ExitStack
 from datetime import datetime
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, NamedTuple, Optional, Union, cast
+from enum import Enum
+from typing import Any, Callable, Dict, Iterator, List, NamedTuple, Optional, TypeVar, Union, cast
 
 import pendulum
+from typing_extensions import TypeGuard
+
 from dagster import check
-from dagster.seven import funcsigs
 
 from ...serdes import whitelist_for_serdes
 from ...utils import ensure_gen, merge_dicts
@@ -25,12 +27,17 @@ from ..storage.tags import check_tags
 from .graph_definition import GraphDefinition
 from .mode import DEFAULT_MODE_NAME
 from .pipeline_definition import PipelineDefinition
-from .run_request import InstigatorType, RunRequest, SkipReason
+from .run_request import RunRequest, SkipReason
 from .target import DirectTarget, RepoRelativeTarget
 from .utils import check_valid_name
 
-if TYPE_CHECKING:
-    from .decorators.schedule import DecoratedScheduleFunction
+T = TypeVar("T")
+
+
+@whitelist_for_serdes
+class DefaultScheduleStatus(Enum):
+    RUNNING = "RUNNING"
+    STOPPED = "STOPPED"
 
 
 class ScheduleEvaluationContext:
@@ -90,6 +97,35 @@ class ScheduleEvaluationContext:
 # Preserve ScheduleExecutionContext for backcompat so type annotations don't break.
 ScheduleExecutionContext = ScheduleEvaluationContext
 
+RunConfig = Dict[str, Any]
+RunRequestIterator = Iterator[Union[RunRequest, SkipReason]]
+
+ScheduleEvaluationFunctionReturn = Union[RunRequest, SkipReason, RunConfig, RunRequestIterator]
+RawScheduleEvaluationFunction = Union[
+    Callable[[ScheduleEvaluationContext], ScheduleEvaluationFunctionReturn],
+    Callable[[], ScheduleEvaluationFunctionReturn],
+]
+
+RunConfigEvaluationFunction = Union[
+    Callable[[ScheduleEvaluationContext], RunConfig],
+    Callable[[], RunConfig],
+]
+
+
+class DecoratedScheduleFunction(NamedTuple):
+    """Wrapper around the decorated schedule function.  Keeps track of both to better support the
+    optimal return value for direct invocation of the evaluation function"""
+
+    decorated_fn: RawScheduleEvaluationFunction
+    wrapped_fn: Callable[[ScheduleEvaluationContext], RunRequestIterator]
+    has_context_arg: bool
+
+
+def is_context_provided(
+    fn: Union[Callable[[ScheduleEvaluationContext], T], Callable[[], T]]
+) -> TypeGuard[Callable[[ScheduleEvaluationContext], T]]:
+    return len(get_function_params(fn)) == 1
+
 
 def build_schedule_context(
     instance: Optional[DagsterInstance] = None, scheduled_execution_time: Optional[datetime] = None
@@ -171,6 +207,8 @@ class ScheduleDefinition:
         description (Optional[str]): A human-readable description of the schedule.
         job (Optional[Union[GraphDefinition, JobDefinition]]): The job that should execute when this
             schedule runs.
+        default_status (DefaultScheduleStatus): Whether the schedule starts as running or not. The default
+            status can be overridden from Dagit or via the GraphQL API.
     """
 
     def __init__(
@@ -179,7 +217,7 @@ class ScheduleDefinition:
         cron_schedule: Optional[str] = None,
         pipeline_name: Optional[str] = None,
         run_config: Optional[Any] = None,
-        run_config_fn: Optional[Callable[..., Any]] = None,
+        run_config_fn: Optional[RunConfigEvaluationFunction] = None,
         tags: Optional[Dict[str, str]] = None,
         tags_fn: Optional[Callable[..., Optional[Dict[str, str]]]] = None,
         solid_selection: Optional[List[Any]] = None,
@@ -188,19 +226,19 @@ class ScheduleDefinition:
         environment_vars: Optional[Dict[str, str]] = None,
         execution_timezone: Optional[str] = None,
         execution_fn: Optional[
-            Union[Callable[[ScheduleEvaluationContext], Any], "DecoratedScheduleFunction"]
+            Union[Callable[[ScheduleEvaluationContext], Any], DecoratedScheduleFunction]
         ] = None,
         description: Optional[str] = None,
         job: Optional[Union[GraphDefinition, PipelineDefinition]] = None,
+        default_status: DefaultScheduleStatus = DefaultScheduleStatus.STOPPED,
     ):
-        from .decorators.schedule import DecoratedScheduleFunction
 
         self._cron_schedule = check.str_param(cron_schedule, "cron_schedule")
 
         if not is_valid_cron_string(self._cron_schedule):
             raise DagsterInvalidDefinitionError(
-                f"Found invalid cron schedule '{self._cron_schedule}' for schedule '{name}''.  "
-                "Dagster recognizes cron expressions consisting of 5 space-separated fields."
+                f"Found invalid cron schedule '{self._cron_schedule}' for schedule '{name}''. "
+                "Dagster recognizes standard cron expressions consisting of 5 fields."
             )
 
         if job is not None:
@@ -249,10 +287,13 @@ class ScheduleDefinition:
                     "Attempted to provide both run_config_fn and run_config as arguments"
                     " to ScheduleDefinition. Must provide only one of the two."
                 )
+
+            # pylint: disable=unused-argument
+            def _default_run_config_fn(context: ScheduleEvaluationContext) -> RunConfig:
+                return check.opt_dict_param(run_config, "run_config")
+
             self._run_config_fn = check.opt_callable_param(
-                run_config_fn,
-                "run_config_fn",
-                default=lambda _context: check.opt_dict_param(run_config, "run_config"),
+                run_config_fn, "run_config_fn", default=_default_run_config_fn
             )
 
             if tags_fn and tags:
@@ -264,7 +305,9 @@ class ScheduleDefinition:
                 check_tags(tags, "tags")
                 tags_fn = lambda _context: tags
             else:
-                tags_fn = check.opt_callable_param(tags_fn, "tags_fn", default=lambda _context: {})
+                tags_fn = check.opt_callable_param(
+                    tags_fn, "tags_fn", default=lambda _context: cast(Dict[str, str], {})
+                )
 
             should_execute = check.opt_callable_param(
                 should_execute, "should_execute", default=lambda _context: True
@@ -287,10 +330,11 @@ class ScheduleDefinition:
                     ScheduleExecutionError,
                     lambda: f"Error occurred during the execution of run_config_fn for schedule {name}",
                 ):
+                    run_config_fn = check.not_none(self._run_config_fn)
                     evaluated_run_config = copy.deepcopy(
-                        self._run_config_fn(context)
-                        if is_context_provided(get_function_params(self._run_config_fn))
-                        else self._run_config_fn()
+                        run_config_fn(context)
+                        if is_context_provided(run_config_fn)
+                        else run_config_fn()  # type: ignore
                     )
 
                 with user_code_error_boundary(
@@ -310,16 +354,18 @@ class ScheduleDefinition:
         if self._execution_timezone:
             try:
                 # Verify that the timezone can be loaded
-                pendulum.timezone(self._execution_timezone)
-            except Exception:
+                pendulum.tz.timezone(self._execution_timezone)
+            except Exception as e:
                 raise DagsterInvalidDefinitionError(
-                    "Invalid execution timezone {timezone} for {schedule_name}".format(
-                        schedule_name=name, timezone=self._execution_timezone
-                    )
-                )
+                    f"Invalid execution timezone {self._execution_timezone} for {name}"
+                ) from e
+
+        self._default_status = check.inst_param(
+            default_status, "default_status", DefaultScheduleStatus
+        )
 
     def __call__(self, *args, **kwargs):
-        from .decorators.schedule import DecoratedScheduleFunction
+        from .decorators.schedule_decorator import DecoratedScheduleFunction
 
         if not isinstance(self._execution_fn, DecoratedScheduleFunction):
             raise DagsterInvalidInvocationError(
@@ -356,13 +402,13 @@ class ScheduleDefinition:
 
             context = context if context else build_schedule_context()
 
-            result = self._execution_fn.decorated_fn(context)
+            result = self._execution_fn.decorated_fn(context)  # type: ignore
         else:
             if len(args) + len(kwargs) > 0:
                 raise DagsterInvalidInvocationError(
                     "Decorated schedule function takes no arguments, but arguments were provided."
                 )
-            result = self._execution_fn.decorated_fn()
+            result = self._execution_fn.decorated_fn()  # type: ignore
 
         if isinstance(result, dict):
             return copy.deepcopy(result)
@@ -377,10 +423,6 @@ class ScheduleDefinition:
     def pipeline_name(self) -> str:
         return self._target.pipeline_name
 
-    @property
-    def job_type(self) -> InstigatorType:
-        return InstigatorType.SCHEDULE
-
     @property
     def solid_selection(self) -> Optional[List[Any]]:
         return self._target.solid_selection
@@ -405,6 +447,12 @@ class ScheduleDefinition:
     def execution_timezone(self) -> Optional[str]:
         return self._execution_timezone
 
+    @property
+    def job(self) -> PipelineDefinition:
+        if isinstance(self._target, DirectTarget):
+            return self._target.pipeline
+        raise DagsterInvalidDefinitionError("No job was provided to ScheduleDefinition.")
+
     def evaluate_tick(self, context: "ScheduleEvaluationContext") -> ScheduleExecutionData:
         """Evaluate schedule using the provided context.
 
@@ -415,32 +463,41 @@ class ScheduleDefinition:
 
         """
 
-        from .decorators.schedule import DecoratedScheduleFunction
-
         check.inst_param(context, "context", ScheduleEvaluationContext)
+        execution_fn: Callable[[ScheduleEvaluationContext], "ScheduleEvaluationFunctionReturn"]
         if isinstance(self._execution_fn, DecoratedScheduleFunction):
             execution_fn = self._execution_fn.wrapped_fn
         else:
-            execution_fn = cast(Callable[[ScheduleEvaluationContext], Any], self._execution_fn)
+            execution_fn = cast(
+                Callable[[ScheduleExecutionContext], "ScheduleEvaluationFunctionReturn"],
+                self._execution_fn,
+            )
+
         result = list(ensure_gen(execution_fn(context)))
 
         skip_message: Optional[str] = None
 
+        run_requests: List[RunRequest] = []
         if not result or result == [None]:
             run_requests = []
             skip_message = "Schedule function returned an empty result"
         elif len(result) == 1:
-            item = result[0]
-            check.inst(item, (SkipReason, RunRequest))
-            run_requests = [item] if isinstance(item, RunRequest) else []
-            skip_message = item.skip_message if isinstance(item, SkipReason) else None
+            item = check.inst(result[0], (SkipReason, RunRequest))
+            if isinstance(item, RunRequest):
+                run_requests = [item]
+                skip_message = None
+            elif isinstance(item, SkipReason):
+                run_requests = []
+                skip_message = item.skip_message
         else:
-            check.is_list(result, of_type=RunRequest)
+            # NOTE: mypy is not correctly reading this cast-- not sure why
+            # (pyright reads it fine). Hence the type-ignores below.
+            result = cast(List[RunRequest], check.is_list(result, of_type=RunRequest))  # type: ignore
             check.invariant(
-                not any(not request.run_key for request in result),
+                not any(not request.run_key for request in result),  # type: ignore
                 "Schedules that return multiple RunRequests must specify a run_key in each RunRequest",
             )
-            run_requests = result
+            run_requests = result  # type: ignore
             skip_message = None
 
         # clone all the run requests with the required schedule tags
@@ -466,6 +523,6 @@ class ScheduleDefinition:
 
         check.failed("Target is not loadable")
 
-
-def is_context_provided(params: List[funcsigs.Parameter]) -> bool:
-    return len(params) == 1
+    @property
+    def default_status(self) -> DefaultScheduleStatus:
+        return self._default_status
