@@ -15,6 +15,7 @@ from typing import (
 )
 
 from dagster import check
+from dagster.config.config_schema import ConfigSchemaType
 from dagster.core.definitions.dependency import NodeHandle
 from dagster.core.definitions.policy import RetryPolicy
 from dagster.core.errors import DagsterInvalidDefinitionError, DagsterInvalidInvocationError
@@ -98,7 +99,7 @@ class SolidDefinition(NodeDefinition):
         input_defs: Sequence[InputDefinition],
         compute_fn: Union[Callable[..., Any], "DecoratedSolidFunction"],
         output_defs: Sequence[OutputDefinition],
-        config_schema: Optional[Union[Dict[str, Any], IDefinitionConfigSchema]] = None,
+        config_schema: Optional[Union[ConfigSchemaType, IDefinitionConfigSchema]] = None,
         description: Optional[str] = None,
         tags: Optional[Dict[str, str]] = None,
         required_resource_keys: Optional[Union[Set[str], FrozenSet[str]]] = None,
