@@ -1,10 +1,10 @@
 import warnings
-from typing import Any, Dict, Optional, Set, Union
+from typing import AbstractSet, Any, Dict, Optional, Set, Union
 
 from dagster import check
 
 from ...definitions.composition import PendingNodeInvocation
-from ...definitions.decorators.graph import graph
+from ...definitions.decorators.graph_decorator import graph
 from ...definitions.dependency import Node
 from ...definitions.hook_definition import HookDefinition
 from ...definitions.mode import ModeDefinition
@@ -116,7 +116,7 @@ class HookContext:
         return self._step_execution_context.mode_def
 
     @property
-    def required_resource_keys(self) -> Set[str]:
+    def required_resource_keys(self) -> AbstractSet[str]:
         return self._required_resource_keys
 
     @property
@@ -163,9 +163,13 @@ class HookContext:
             * a dictionary from mapping key to corresponding value in the mapped case
         """
         results: Dict[str, Union[Any, Dict[str, Any]]] = {}
+        captured = self._step_execution_context.step_output_capture
+
+        if captured is None:
+            check.failed("Outputs were unexpectedly not captured for hook")
 
         # make the returned values more user-friendly
-        for step_output_handle, value in self._step_execution_context.step_output_capture.items():
+        for step_output_handle, value in captured.items():
             if step_output_handle.mapping_key:
                 if results.get(step_output_handle.output_name) is None:
                     results[step_output_handle.output_name] = {
@@ -193,8 +197,8 @@ class UnboundHookContext(HookContext):
         job_name: Optional[str],
         op_exception: Optional[Exception],
     ):  # pylint: disable=super-init-not-called
-        from ..context_creation_pipeline import initialize_console_manager
         from ..build_resources import build_resources
+        from ..context_creation_pipeline import initialize_console_manager
 
         self._mode_def = mode_def
 
@@ -356,7 +360,7 @@ class BoundHookContext(HookContext):
         return self._mode_def
 
     @property
-    def required_resource_keys(self) -> Set[str]:
+    def required_resource_keys(self) -> AbstractSet[str]:
         return self._hook_def.required_resource_keys
 
     @property
