@@ -1,21 +1,32 @@
 import warnings
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, Iterator, List, Optional, Sequence, Union, cast
 
 from dagster import check
-from dagster.core.definitions.events import AssetKey
-from dagster.core.definitions.solid import SolidDefinition
+from dagster.core.definitions.events import (
+    AssetKey,
+    AssetMaterialization,
+    AssetObservation,
+    Materialization,
+    MetadataEntry,
+    PartitionMetadataEntry,
+)
+from dagster.core.definitions.op_definition import OpDefinition
+from dagster.core.definitions.partition_key_range import PartitionKeyRange
+from dagster.core.definitions.solid_definition import SolidDefinition
+from dagster.core.definitions.time_window_partitions import TimeWindow
 from dagster.core.errors import DagsterInvariantViolationError
 from dagster.core.execution.plan.utils import build_resources_for_manager
 
 if TYPE_CHECKING:
-    from dagster.core.execution.context.system import StepExecutionContext
-    from dagster.core.types.dagster_type import DagsterType
     from dagster.core.definitions import PipelineDefinition
+    from dagster.core.definitions.resource_definition import Resources
+    from dagster.core.events import DagsterEvent
+    from dagster.core.execution.context.system import StepExecutionContext
+    from dagster.core.execution.plan.outputs import StepOutputHandle
+    from dagster.core.execution.plan.plan import ExecutionPlan
     from dagster.core.log_manager import DagsterLogManager
     from dagster.core.system_config.objects import ResolvedRunConfig
-    from dagster.core.definitions.resource import Resources
-    from dagster.core.execution.plan.plan import ExecutionPlan
-    from dagster.core.execution.plan.outputs import StepOutputHandle
+    from dagster.core.types.dagster_type import DagsterType
 
 RUN_ID_PLACEHOLDER = "__EPHEMERAL_RUN_ID"
 
@@ -41,6 +52,7 @@ class OutputContext:
             initializes the RootInputManager.
         resources (Optional[Resources]): The resources required by the output manager, specified by the
             `required_resource_keys` parameter.
+        op_def (Optional[OpDefinition]): The definition of the op that produced the output.
     """
 
     def __init__(
@@ -59,8 +71,9 @@ class OutputContext:
         resource_config: Optional[Dict[str, Any]] = None,
         resources: Optional[Union["Resources", Dict[str, Any]]] = None,
         step_context: Optional["StepExecutionContext"] = None,
+        op_def: Optional["OpDefinition"] = None,
     ):
-        from dagster.core.definitions.resource import Resources, IContainsGenerator
+        from dagster.core.definitions.resource_definition import IContainsGenerator, Resources
         from dagster.core.execution.build_resources import build_resources
 
         self._step_key = step_key
@@ -70,7 +83,10 @@ class OutputContext:
         self._metadata = metadata
         self._mapping_key = mapping_key
         self._config = config
-        self._solid_def = solid_def
+        check.invariant(
+            solid_def is None or op_def is None, "Can't provide both a solid_def and an op_def arg"
+        )
+        self._solid_def = solid_def or op_def
         self._dagster_type = dagster_type
         self._log = log_manager
         self._version = version
@@ -88,6 +104,10 @@ class OutputContext:
             self._resources_contain_cm = isinstance(self._resources, IContainsGenerator)
             self._cm_scope_entered = False
 
+        self._events: List["DagsterEvent"] = []
+        self._user_events: List[Union[AssetMaterialization, AssetObservation, Materialization]] = []
+        self._metadata_entries: Optional[List[Union[MetadataEntry, PartitionMetadataEntry]]] = None
+
     def __enter__(self):
         if self._resources_cm:
             self._cm_scope_entered = True
@@ -163,6 +183,16 @@ class OutputContext:
 
         return self._solid_def
 
+    @property
+    def op_def(self) -> "OpDefinition":
+        if self._solid_def is None:
+            raise DagsterInvariantViolationError(
+                "Attempting to access op_def, "
+                "but it was not provided when constructing the OutputContext"
+            )
+
+        return cast(OpDefinition, self._solid_def)
+
     @property
     def dagster_type(self) -> "DagsterType":
         if self._dagster_type is None:
@@ -227,6 +257,53 @@ class OutputContext:
 
         return self._step_context
 
+    @property
+    def has_partition_key(self) -> bool:
+        """Whether the current run is a partitioned run"""
+        return self.step_context.has_partition_key
+
+    @property
+    def partition_key(self) -> str:
+        """The partition key for the current run.
+
+        Raises an error if the current run is not a partitioned run.
+        """
+        return self.step_context.partition_key
+
+    @property
+    def has_asset_partitions(self) -> bool:
+        if self._step_context is not None:
+            return self._step_context.has_asset_partitions_for_output(self.name)
+        else:
+            return False
+
+    @property
+    def asset_partition_key(self) -> str:
+        """The partition key for output asset.
+
+        Raises an error if the output asset has no partitioning, or if the run covers a partition
+        range for the output asset.
+        """
+        return self.step_context.asset_partition_key_for_output(self.name)
+
+    @property
+    def asset_partition_key_range(self) -> PartitionKeyRange:
+        """The partition key range for output asset.
+
+        Raises an error if the output asset has no partitioning.
+        """
+        return self.step_context.asset_partition_key_range_for_output(self.name)
+
+    @property
+    def asset_partitions_time_window(self) -> TimeWindow:
+        """The time window for the partitions of the output asset.
+
+        Raises an error if either of the following are true:
+        - The output asset has no partitioning.
+        - The output asset is not partitioned with a TimeWindowPartitionsDefinition.
+        """
+        return self.step_context.asset_partitions_time_window_for_output(self.name)
+
     def get_run_scoped_output_identifier(self) -> List[str]:
         """Utility method to get a collection of identifiers that as a whole represent a unique
         step output.
@@ -307,6 +384,132 @@ class OutputContext:
 
         return identifier
 
+    def get_asset_output_identifier(self) -> Sequence[str]:
+        if self.asset_key is not None:
+            if self.has_asset_partitions:
+                return self.asset_key.path + [self.asset_partition_key]
+            else:
+                return self.asset_key.path
+        else:
+            check.failed("Can't get asset output identifier for an output with no asset key")
+
+    def log_event(
+        self, event: Union[AssetObservation, AssetMaterialization, Materialization]
+    ) -> None:
+        """Log an AssetMaterialization or AssetObservation from within the body of an io manager's `handle_output` method.
+
+        Events logged with this method will appear in the event log.
+
+        Args:
+            event (Union[AssetMaterialization, Materialization, AssetObservation]): The event to log.
+
+        Examples:
+
+        .. code-block:: python
+
+            from dagster import IOManager, AssetMaterialization
+
+            class MyIOManager(IOManager):
+                def handle_output(self, context, obj):
+                    context.log_event(AssetMaterialization("foo"))
+        """
+        from dagster.core.events import DagsterEvent
+
+        if isinstance(event, (AssetMaterialization, Materialization)):
+            if self._step_context:
+                self._events.append(
+                    DagsterEvent.asset_materialization(
+                        self._step_context,
+                        event,
+                        self._step_context.get_input_lineage(),
+                    )
+                )
+            self._user_events.append(event)
+        elif isinstance(event, AssetObservation):
+            if self._step_context:
+                self._events.append(DagsterEvent.asset_observation(self._step_context, event))
+            self._user_events.append(event)
+        else:
+            check.failed("Unexpected event {event}".format(event=event))
+
+    def consume_events(self) -> Iterator["DagsterEvent"]:
+        """Pops and yields all user-generated events that have been recorded from this context.
+
+        If consume_events has not yet been called, this will yield all logged events since the call to `handle_output`. If consume_events has been called, it will yield all events since the last time consume_events was called. Designed for internal use. Users should never need to invoke this method.
+        """
+
+        events = self._events
+        self._events = []
+        yield from events
+
+    def get_logged_events(
+        self,
+    ) -> List[Union[AssetMaterialization, Materialization, AssetObservation]]:
+        """Retrieve the list of user-generated events that were logged via the context.
+
+
+        User-generated events that were yielded will not appear in this list.
+
+        **Examples:**
+
+        .. code-block:: python
+
+            from dagster import IOManager, build_output_context, AssetMaterialization
+
+            class MyIOManager(IOManager):
+                def handle_output(self, context, obj):
+                    ...
+
+            def test_handle_output():
+                mgr = MyIOManager()
+                context = build_output_context()
+                mgr.handle_output(context)
+                all_user_events = context.get_logged_events()
+                materializations = [event for event in all_user_events if isinstance(event, AssetMaterialization)]
+                ...
+        """
+
+        return self._user_events
+
+    def add_output_metadata(self, metadata: Dict[str, Any]) -> None:
+        """Add a dictionary of metadata to the handled output.
+
+        Metadata entries added will show up in the HANDLED_OUTPUT and ASSET_MATERIALIZATION events for the run.
+
+        Args:
+            metadata (Dict[str, Any]): A metadata dictionary to log
+
+        Examples:
+
+        .. code-block:: python
+
+            from dagster import IOManager
+
+            class MyIOManager(IOManager):
+                def handle_output(self, context, obj):
+                    context.add_output_metadata({"foo": "bar"})
+        """
+        from dagster.core.definitions.metadata import normalize_metadata
+
+        self._metadata_entries = normalize_metadata(metadata, [])
+
+    def get_logged_metadata_entries(
+        self,
+    ) -> List[Union[MetadataEntry, PartitionMetadataEntry]]:
+        """Get the list of metadata entries that have been logged for use with this output."""
+        return self._metadata_entries or []
+
+    def consume_logged_metadata_entries(
+        self,
+    ) -> List[Union[MetadataEntry, PartitionMetadataEntry]]:
+        """Pops and yields all user-generated metadata entries that have been recorded from this context.
+
+        If consume_logged_metadata_entries has not yet been called, this will yield all logged events since the call to `handle_output`. If consume_logged_metadata_entries has been called, it will yield all events since the last time consume_logged_metadata_entries was called. Designed for internal use. Users should never need to invoke this method.
+        """
+        result = self._metadata_entries
+        self._metadata_entries = []
+        return result or []
+
 
 def get_output_context(
     execution_plan: "ExecutionPlan",
@@ -398,6 +601,7 @@ def build_output_context(
     resource_config: Optional[Dict[str, Any]] = None,
     resources: Optional[Dict[str, Any]] = None,
     solid_def: Optional[SolidDefinition] = None,
+    op_def: Optional[OpDefinition] = None,
 ) -> "OutputContext":
     """Builds output context from provided parameters.
 
@@ -421,6 +625,7 @@ def build_output_context(
             For a given key, you can provide either an actual instance of an object, or a resource
             definition.
         solid_def (Optional[SolidDefinition]): The definition of the solid that produced the output.
+        op_def (Optional[OpDefinition]): The definition of the solid that produced the output.
 
     Examples:
 
@@ -432,8 +637,8 @@ def build_output_context(
                 do_something
 
     """
-    from dagster.core.types.dagster_type import DagsterType
     from dagster.core.execution.context_creation_pipeline import initialize_console_manager
+    from dagster.core.types.dagster_type import DagsterType
 
     step_key = check.opt_str_param(step_key, "step_key")
     name = check.opt_str_param(name, "name")
@@ -445,6 +650,7 @@ def build_output_context(
     resource_config = check.opt_dict_param(resource_config, "resource_config", key_type=str)
     resources = check.opt_dict_param(resources, "resources", key_type=str)
     solid_def = check.opt_inst_param(solid_def, "solid_def", SolidDefinition)
+    op_def = check.opt_inst_param(op_def, "op_def", OpDefinition)
 
     return OutputContext(
         step_key=step_key,
@@ -461,4 +667,5 @@ def build_output_context(
         resource_config=resource_config,
         resources=resources,
         step_context=None,
+        op_def=op_def,
     )
