@@ -57,7 +57,9 @@ if TYPE_CHECKING:
     from dagster.core.executor.base import Executor
 
 
-def initialize_console_manager(pipeline_run: Optional[PipelineRun]) -> DagsterLogManager:
+def initialize_console_manager(
+    pipeline_run: Optional[PipelineRun], instance: Optional[DagsterInstance] = None
+) -> DagsterLogManager:
     # initialize default colored console logger
     loggers = []
     for logger_def, logger_config in default_system_loggers():
@@ -68,7 +70,7 @@ def initialize_console_manager(pipeline_run: Optional[PipelineRun]) -> DagsterLo
                 )
             )
         )
-    return DagsterLogManager.create(loggers=loggers, pipeline_run=pipeline_run)
+    return DagsterLogManager.create(loggers=loggers, pipeline_run=pipeline_run, instance=instance)
 
 
 def executor_def_from_config(
@@ -428,8 +430,8 @@ def scoped_pipeline_context(
     run_config: Dict[str, Any],
     pipeline_run: PipelineRun,
     instance: DagsterInstance,
-    scoped_resources_builder_cm: Optional[
-        Callable[..., EventGenerationManager[ScopedResourcesBuilder]]
+    scoped_resources_builder_cm: Callable[
+        ..., EventGenerationManager[ScopedResourcesBuilder]
     ] = resource_initialization_manager,
     raise_on_error: Optional[bool] = False,
 ) -> Generator[PlanExecutionContext, None, None]:
