@@ -14,6 +14,7 @@ from dagster.core.definitions import (
     Output,
 )
 from dagster.core.errors import DagsterExecutionStepExecutionError, DagsterInvariantViolationError
+from dagster.core.events import DagsterEvent
 from dagster.core.execution.context.compute import SolidExecutionContext
 from dagster.core.execution.context.system import StepExecutionContext
 from dagster.core.system_config.objects import ResolvedRunConfig
@@ -29,6 +30,7 @@ SolidOutputUnion = Union[
     Materialization,
     ExpectationResult,
     AssetObservation,
+    DagsterEvent,
 ]
 
 
@@ -56,6 +58,7 @@ def create_step_outputs(
                 is_dynamic=output_def.is_dynamic,
                 is_asset=output_def.is_asset,
                 should_materialize=output_def.name in config_output_names,
+                asset_key=output_def.hardcoded_asset_key,
             ),
         )
         for name, output_def in solid.definition.output_dict.items()
@@ -72,6 +75,7 @@ def _validate_event(event: Any, step_context: StepExecutionContext) -> SolidOutp
             Materialization,
             ExpectationResult,
             AssetObservation,
+            DagsterEvent,
         ),
     ):
         raise DagsterInvariantViolationError(
@@ -108,7 +112,8 @@ def _yield_compute_results(
 ) -> Iterator[SolidOutputUnion]:
     check.inst_param(step_context, "step_context", StepExecutionContext)
 
-    user_event_generator = compute_fn(SolidExecutionContext(step_context), inputs)
+    context = SolidExecutionContext(step_context)
+    user_event_generator = compute_fn(context, inputs)
 
     if isinstance(user_event_generator, Output):
         raise DagsterInvariantViolationError(
@@ -141,8 +146,13 @@ def _yield_compute_results(
         ),
         user_event_generator,
     ):
+        if context.has_events():
+            yield from context.consume_events()
         yield _validate_event(event, step_context)
 
+    if context.has_events():
+        yield from context.consume_events()
+
 
 def execute_core_compute(
     step_context: StepExecutionContext, inputs: Dict[str, Any], compute_fn
