@@ -7,6 +7,7 @@ from dagster.core.definitions import (
     MetadataEntry,
     NodeHandle,
 )
+from dagster.core.definitions.events import AssetKey
 from dagster.serdes import whitelist_for_serdes
 
 from .handle import UnresolvedStepHandle
@@ -22,6 +23,7 @@ class StepOutputProperties(
             ("is_dynamic", bool),
             ("is_asset", bool),
             ("should_materialize", bool),
+            ("asset_key", Optional[AssetKey]),
         ],
     )
 ):
@@ -31,6 +33,7 @@ class StepOutputProperties(
         is_dynamic: bool,
         is_asset: bool,
         should_materialize: bool,
+        asset_key: Optional[AssetKey] = None,
     ):
         return super(StepOutputProperties, cls).__new__(
             cls,
@@ -38,6 +41,7 @@ class StepOutputProperties(
             check.bool_param(is_dynamic, "is_dynamic"),
             check.bool_param(is_asset, "is_asset"),
             check.bool_param(should_materialize, "should_materialize"),
+            check.opt_inst_param(asset_key, "asset_key", AssetKey),
         )
 
 
@@ -85,6 +89,12 @@ class StepOutput(
     def should_materialize(self) -> bool:
         return self.properties.should_materialize
 
+    @property
+    def asset_key(self) -> Optional[AssetKey]:
+        if not self.is_asset:
+            return None
+        return self.properties.asset_key
+
 
 @whitelist_for_serdes
 class StepOutputData(
