@@ -1,3 +1,4 @@
+import enum
 from collections import defaultdict
 from typing import Dict, List, Optional, Tuple
 
@@ -30,6 +31,11 @@ def _in_tracking_dict(handle, tracking):
         return handle.to_key() in tracking
 
 
+class ReexecutionPolicy(enum.Enum):
+    ALL_STEPS = "ALL_STEPS"
+    FROM_FAILURE = "FROM_FAILURE"
+
+
 def get_retry_steps_from_parent_run(
     instance, parent_run_id: str = None, parent_run: PipelineRun = None
 ) -> Tuple[List[str], Optional[KnownExecutionState]]:
