@@ -1,18 +1,22 @@
+import multiprocessing
 import os
 import sys
+from typing import List, Optional
 
-from dagster import EventMetadataEntry, check
-from dagster.core.definitions.reconstructable import ReconstructablePipeline
-from dagster.core.errors import DagsterExecutionInterruptedError, DagsterSubprocessError
+from dagster import MetadataEntry, check
+from dagster.core.errors import (
+    DagsterExecutionInterruptedError,
+    DagsterSubprocessError,
+    DagsterUnmetExecutorRequirementsError,
+)
 from dagster.core.events import DagsterEvent, EngineEventData
 from dagster.core.execution.api import create_execution_plan, execute_plan_iterator
-from dagster.core.execution.context.system import SystemPipelineExecutionContext
+from dagster.core.execution.context.system import PlanOrchestrationContext
 from dagster.core.execution.plan.objects import StepFailureData
 from dagster.core.execution.plan.plan import ExecutionPlan
 from dagster.core.execution.retries import RetryMode
 from dagster.core.executor.base import Executor
 from dagster.core.instance import DagsterInstance
-from dagster.seven import multiprocessing
 from dagster.utils import start_termination_thread
 from dagster.utils.error import serializable_error_info_from_exc_info
 from dagster.utils.timing import format_duration, time_execution_scope
@@ -28,7 +32,7 @@ from .child_process_executor import (
 DELEGATE_MARKER = "multiprocess_subprocess_init"
 
 
-class InProcessExecutorChildProcessCommand(ChildProcessCommand):
+class MultiprocessExecutorChildProcessCommand(ChildProcessCommand):
     def __init__(
         self,
         run_config,
@@ -57,17 +61,17 @@ class InProcessExecutorChildProcessCommand(ChildProcessCommand):
                 pipeline=pipeline,
                 run_config=self.run_config,
                 mode=self.pipeline_run.mode,
-                step_keys_to_execute=self.pipeline_run.step_keys_to_execute,
+                step_keys_to_execute=[self.step_key],
                 known_state=self.known_state,
-            ).build_subset_plan([self.step_key])
+            )
 
             yield instance.report_engine_event(
                 "Executing step {} in subprocess".format(self.step_key),
                 self.pipeline_run,
                 EngineEventData(
                     [
-                        EventMetadataEntry.text(str(os.getpid()), "pid"),
-                        EventMetadataEntry.text(self.step_key, "step_key"),
+                        MetadataEntry("pid", value=str(os.getpid())),
+                        MetadataEntry("step_key", value=self.step_key),
                     ],
                     marker_end=DELEGATE_MARKER,
                 ),
@@ -77,6 +81,7 @@ class InProcessExecutorChildProcessCommand(ChildProcessCommand):
 
             yield from execute_plan_iterator(
                 execution_plan,
+                pipeline,
                 self.pipeline_run,
                 run_config=self.run_config,
                 retry_mode=self.retry_mode.for_inner_plan(),
@@ -85,25 +90,65 @@ class InProcessExecutorChildProcessCommand(ChildProcessCommand):
 
 
 class MultiprocessExecutor(Executor):
-    def __init__(self, pipeline, retries, max_concurrent=None):
-
-        self.pipeline = check.inst_param(pipeline, "pipeline", ReconstructablePipeline)
+    def __init__(
+        self,
+        retries: RetryMode,
+        max_concurrent: int,
+        start_method: Optional[str] = None,
+        explicit_forkserver_preload: Optional[List[str]] = None,
+    ):
         self._retries = check.inst_param(retries, "retries", RetryMode)
         max_concurrent = max_concurrent if max_concurrent else multiprocessing.cpu_count()
-        self.max_concurrent = check.int_param(max_concurrent, "max_concurrent")
+        self._max_concurrent = check.int_param(max_concurrent, "max_concurrent")
+        start_method = check.opt_str_param(start_method, "start_method")
+        valid_starts = multiprocessing.get_all_start_methods()
+
+        if start_method is None:
+            start_method = "spawn"
+
+        if start_method not in valid_starts:
+            raise DagsterUnmetExecutorRequirementsError(
+                f"The selected start_method '{start_method}' is not available. "
+                f"Only {valid_starts} are valid options on {sys.platform} python {sys.version}.",
+            )
+        self._start_method = start_method
+        self._explicit_forkserver_preload = explicit_forkserver_preload
 
     @property
     def retries(self):
         return self._retries
 
-    def execute(self, pipeline_context, execution_plan):
-        check.inst_param(pipeline_context, "pipeline_context", SystemPipelineExecutionContext)
+    def execute(self, plan_context, execution_plan):
+        check.inst_param(plan_context, "plan_context", PlanOrchestrationContext)
         check.inst_param(execution_plan, "execution_plan", ExecutionPlan)
 
-        limit = self.max_concurrent
+        pipeline = plan_context.reconstructable_pipeline
+
+        multiproc_ctx = multiprocessing.get_context(self._start_method)
+        if self._start_method == "forkserver":
+            # if explicitly listed in config we will use that
+            if self._explicit_forkserver_preload is not None:
+                preload = self._explicit_forkserver_preload
+
+            # or if the reconstructable pipeline has a module target, we will use that
+            elif pipeline.get_module():
+                preload = [pipeline.get_module()]
+
+            # base case is to preload the dagster library
+            else:
+                preload = ["dagster"]
+
+            # we import this module first to avoid user code like
+            # pyspark.serializers._hijack_namedtuple from breaking us
+            if "dagster.core.executor.multiprocess" not in preload:
+                preload = ["dagster.core.executor.multiprocess"] + preload
+
+            multiproc_ctx.set_forkserver_preload(preload)
+
+        limit = self._max_concurrent
 
         yield DagsterEvent.engine_event(
-            pipeline_context,
+            plan_context,
             "Executing steps using multiprocess executor: parent process (pid: {pid})".format(
                 pid=os.getpid()
             ),
@@ -125,7 +170,7 @@ class MultiprocessExecutor(Executor):
                 while (not stopping and not active_execution.is_complete) or active_iters:
                     if active_execution.check_for_interrupts():
                         yield DagsterEvent.engine_event(
-                            pipeline_context,
+                            plan_context,
                             "Multiprocess executor: received termination signal - "
                             "forwarding to active child processes",
                             EngineEventData.interrupted(list(term_events.keys())),
@@ -145,13 +190,16 @@ class MultiprocessExecutor(Executor):
                             break
 
                         for step in steps:
-                            step_context = pipeline_context.for_step(step)
-                            term_events[step.key] = multiprocessing.Event()
-                            active_iters[step.key] = self.execute_step_out_of_process(
+                            step_context = plan_context.for_step(step)
+                            term_events[step.key] = multiproc_ctx.Event()
+                            active_iters[step.key] = execute_step_out_of_process(
+                                multiproc_ctx,
+                                pipeline,
                                 step_context,
                                 step,
                                 errors,
                                 term_events,
+                                self.retries,
                                 active_execution.get_known_state(),
                             )
 
@@ -171,7 +219,7 @@ class MultiprocessExecutor(Executor):
                                 sys.exc_info()
                             )
                             yield DagsterEvent.engine_event(
-                                pipeline_context,
+                                plan_context,
                                 (
                                     "Multiprocess executor: child process for step {step_key} "
                                     "unexpectedly exited with code {exit_code}"
@@ -180,7 +228,7 @@ class MultiprocessExecutor(Executor):
                                 step_handle=active_execution.get_step_by_key(key).handle,
                             )
                             step_failure_event = DagsterEvent.step_failure_event(
-                                step_context=pipeline_context.for_step(
+                                step_context=plan_context.for_step(
                                     active_execution.get_step_by_key(key)
                                 ),
                                 step_failure_data=StepFailureData(
@@ -197,10 +245,10 @@ class MultiprocessExecutor(Executor):
                     for key in empty_iters:
                         del active_iters[key]
                         del term_events[key]
-                        active_execution.verify_complete(pipeline_context, key)
+                        active_execution.verify_complete(plan_context, key)
 
                     # process skipped and abandoned steps
-                    yield from active_execution.plan_events_iterator(pipeline_context)
+                    yield from active_execution.plan_events_iterator(plan_context)
 
                 errs = {pid: err for pid, err in errors.items() if err}
 
@@ -217,7 +265,7 @@ class MultiprocessExecutor(Executor):
                     )
                 ):
                     yield DagsterEvent.engine_event(
-                        pipeline_context,
+                        plan_context,
                         "Multiprocess executor: interrupted all active child processes",
                         event_specific_data=EngineEventData(),
                     )
@@ -236,37 +284,47 @@ class MultiprocessExecutor(Executor):
                     )
 
         yield DagsterEvent.engine_event(
-            pipeline_context,
+            plan_context,
             "Multiprocess executor: parent process exiting after {duration} (pid: {pid})".format(
                 duration=format_duration(timer_result.millis), pid=os.getpid()
             ),
             event_specific_data=EngineEventData.multiprocess(os.getpid()),
         )
 
-    def execute_step_out_of_process(self, step_context, step, errors, term_events, known_state):
-        command = InProcessExecutorChildProcessCommand(
-            run_config=step_context.run_config,
-            pipeline_run=step_context.pipeline_run,
-            step_key=step.key,
-            instance_ref=step_context.instance.get_ref(),
-            term_event=term_events[step.key],
-            recon_pipeline=self.pipeline,
-            retry_mode=self.retries,
-            known_state=known_state,
-        )
 
-        yield DagsterEvent.engine_event(
-            step_context,
-            "Launching subprocess for {}".format(step.key),
-            EngineEventData(marker_start=DELEGATE_MARKER),
-            step_handle=step.handle,
-        )
+def execute_step_out_of_process(
+    multiproc_ctx,
+    pipeline,
+    step_context,
+    step,
+    errors,
+    term_events,
+    retries,
+    known_state,
+):
+    command = MultiprocessExecutorChildProcessCommand(
+        run_config=step_context.run_config,
+        pipeline_run=step_context.pipeline_run,
+        step_key=step.key,
+        instance_ref=step_context.instance.get_ref(),
+        term_event=term_events[step.key],
+        recon_pipeline=pipeline,
+        retry_mode=retries,
+        known_state=known_state,
+    )
 
-        for ret in execute_child_process_command(command):
-            if ret is None or isinstance(ret, DagsterEvent):
-                yield ret
-            elif isinstance(ret, ChildProcessEvent):
-                if isinstance(ret, ChildProcessSystemErrorEvent):
-                    errors[ret.pid] = ret.error_info
-            else:
-                check.failed("Unexpected return value from child process {}".format(type(ret)))
+    yield DagsterEvent.engine_event(
+        step_context,
+        "Launching subprocess for {}".format(step.key),
+        EngineEventData(marker_start=DELEGATE_MARKER),
+        step_handle=step.handle,
+    )
+
+    for ret in execute_child_process_command(multiproc_ctx, command):
+        if ret is None or isinstance(ret, DagsterEvent):
+            yield ret
+        elif isinstance(ret, ChildProcessEvent):
+            if isinstance(ret, ChildProcessSystemErrorEvent):
+                errors[ret.pid] = ret.error_info
+        else:
+            check.failed("Unexpected return value from child process {}".format(type(ret)))
