@@ -1,13 +1,11 @@
-from abc import ABCMeta, abstractproperty
-
-import six
+from abc import ABC, abstractmethod
 
 from dagster import check
 
 from .pipeline_index import PipelineIndex
 
 
-class RepresentedPipeline(six.with_metaclass(ABCMeta)):
+class RepresentedPipeline(ABC):
     """
     RepresentedPipeline is a base class for ExternalPipeline or HistoricalPipeline.
 
@@ -35,11 +33,13 @@ class RepresentedPipeline(six.with_metaclass(ABCMeta)):
 
     # Snapshot things
 
-    @abstractproperty
+    @property
+    @abstractmethod
     def computed_pipeline_snapshot_id(self):
         pass
 
-    @abstractproperty
+    @property
+    @abstractmethod
     def identifying_pipeline_snapshot_id(self):
         pass
 
@@ -101,10 +101,15 @@ class RepresentedPipeline(six.with_metaclass(ABCMeta)):
         return self._pipeline_index.dep_structure_index
 
     # Solids
-    def get_solid_def_snap(self, solid_def_name):
+    def get_node_def_snap(self, solid_def_name):
         check.str_param(solid_def_name, "solid_def_name")
-        return self._pipeline_index.get_solid_def_snap(solid_def_name)
+        return self._pipeline_index.get_node_def_snap(solid_def_name)
 
     def get_dep_structure_index(self, solid_def_name):
         check.str_param(solid_def_name, "solid_def_name")
         return self._pipeline_index.get_dep_structure_index(solid_def_name)
+
+    # Graph
+
+    def get_graph_name(self):
+        return self._pipeline_index.pipeline_snapshot.graph_def_name
