@@ -5,6 +5,7 @@ import signal
 import sys
 import tempfile
 import time
+from collections import defaultdict
 from contextlib import ExitStack, contextmanager
 
 import pendulum
@@ -120,7 +121,7 @@ def instance_for_test(overrides=None, set_dagster_home=True, temp_dir=None):
                 environ({"DAGSTER_HOME": temp_dir, "DAGSTER_DISABLE_TELEMETRY": "yes"})
             )
 
-        with open(os.path.join(temp_dir, "dagster.yaml"), "w") as fd:
+        with open(os.path.join(temp_dir, "dagster.yaml"), "w", encoding="utf8") as fd:
             yaml.dump(instance_overrides, fd, default_flow_style=False)
 
         with DagsterInstance.from_config(temp_dir) as instance:
@@ -496,6 +497,31 @@ def get_logger_output_from_capfd(capfd, logger_name):
     )
 
 
+def _step_events(instance, run):
+    events_by_step = defaultdict(set)
+    logs = instance.all_logs(run.run_id)
+    for record in logs:
+        if not record.is_dagster_event or not record.step_key:
+            continue
+        events_by_step[record.step_key] = record.dagster_event.event_type_value
+    return events_by_step
+
+
+def step_did_not_run(instance, run, step_name):
+    step_events = _step_events(instance, run)[step_name]
+    return len(step_events) == 0
+
+
+def step_succeeded(instance, run, step_name):
+    step_events = _step_events(instance, run)[step_name]
+    return "STEP_SUCCESS" in step_events
+
+
+def step_failed(instance, run, step_name):
+    step_events = _step_events(instance, run)[step_name]
+    return "STEP_FAILURE" in step_events
+
+
 def test_counter():
     @traced
     async def foo():
