@@ -2,11 +2,12 @@ import logging
 import sys
 import time
 import uuid
-from abc import abstractclassmethod, abstractmethod
+from abc import abstractmethod
 from collections import deque
 from contextlib import AbstractContextManager
 
 import pendulum
+
 from dagster import DagsterInstance, check
 from dagster.core.telemetry import DAEMON_ALIVE, log_action
 from dagster.core.workspace import IWorkspace
@@ -43,7 +44,8 @@ class DagsterDaemon(AbstractContextManager):
 
         self._first_error_logged = False
 
-    @abstractclassmethod
+    @classmethod
+    @abstractmethod
     def daemon_type(cls):
         """
         returns: str
@@ -90,7 +92,7 @@ class DagsterDaemon(AbstractContextManager):
                             except Exception:
                                 error_info = serializable_error_info_from_exc_info(sys.exc_info())
                                 self._logger.error(
-                                    "Caught error, daemon loop will restart:\n{}".format(error_info)
+                                    "Caught error, daemon loop will restart:\n%s", error_info
                                 )
                                 self._errors.appendleft((error_info, pendulum.now("UTC")))
                                 daemon_generator.close()
@@ -105,9 +107,8 @@ class DagsterDaemon(AbstractContextManager):
                                     )
                                 except Exception:
                                     self._logger.error(
-                                        "Failed to add heartbeat: \n{}".format(
-                                            serializable_error_info_from_exc_info(sys.exc_info())
-                                        )
+                                        "Failed to add heartbeat: \n%s",
+                                        serializable_error_info_from_exc_info(sys.exc_info()),
                                     )
                     finally:
                         # cleanup the generator if it was stopped part-way through
@@ -140,15 +141,14 @@ class DagsterDaemon(AbstractContextManager):
             and last_stored_heartbeat
             and last_stored_heartbeat.daemon_id != daemon_uuid
         ):
-            self._logger.warning(
-                "Taking over from another {} daemon process. If this "
-                "message reoccurs, you may have multiple daemons running which is not supported. "
-                "Last heartbeat daemon id: {}, "
-                "Current daemon_id: {}".format(
-                    daemon_type,
-                    last_stored_heartbeat.daemon_id,
-                    daemon_uuid,
-                )
+            self._logger.error(
+                "Another %s daemon is still sending heartbeats. You likely have multiple "
+                "daemon processes running at once, which is not supported. "
+                "Last heartbeat daemon id: %s, "
+                "Current daemon_id: %s",
+                daemon_type,
+                last_stored_heartbeat.daemon_id,
+                daemon_uuid,
             )
 
         self._last_heartbeat_time = curr_time
@@ -196,7 +196,7 @@ class IntervalDaemon(DagsterDaemon):
                 yield from self.run_iteration(instance, workspace)
             except Exception:
                 error_info = serializable_error_info_from_exc_info(sys.exc_info())
-                self._logger.error("Caught error:\n{}".format(error_info))
+                self._logger.error("Caught error:\n%s", error_info)
                 yield error_info
             while time.time() - start_time < self.interval_seconds:
                 yield
