@@ -40,12 +40,12 @@ class JsonFileHandler(logging.Handler):
 
             log_dict.update(dagster_meta_dict)
 
-            with open(self.json_path, "a") as ff:
+            with open(self.json_path, "a", encoding="utf8") as ff:
                 text_line = seven.json.dumps(log_dict)
                 ff.write(text_line + "\n")
         # Need to catch Exception here, so disabling lint
         except Exception as e:  # pylint: disable=W0703
-            logging.critical("[{}] Error during logging!".format(self.__class__.__name__))
+            logging.critical("[%s] Error during logging!", self.__class__.__name__)
             logging.exception(str(e))
 
 
@@ -88,13 +88,13 @@ class JsonEventLoggerHandler(logging.Handler):
     def emit(self, record):
         try:
             event_record = self.construct_event_record(record)
-            with open(self.json_path, "a") as ff:
+            with open(self.json_path, "a", encoding="utf8") as ff:
                 text_line = seven.json.dumps(event_record.to_dict())
                 ff.write(text_line + "\n")
 
         # Need to catch Exception here, so disabling lint
         except Exception as e:  # pylint: disable=W0703
-            logging.critical("[{}] Error during logging!".format(self.__class__.__name__))
+            logging.critical("[%s] Error during logging!", self.__class__.__name__)
             logging.exception(str(e))
 
 
@@ -116,7 +116,7 @@ class StructuredLoggerHandler(logging.Handler):
             )
         # Need to catch Exception here, so disabling lint
         except Exception as e:  # pylint: disable=W0703
-            logging.critical("[{}] Error during logging!".format(self.__class__.__name__))
+            logging.critical("[%s] Error during logging!", self.__class__.__name__)
             logging.exception(str(e))
 
 
