@@ -11,25 +11,26 @@ from dagster import (
     DependencyDefinition,
     Failure,
     ModeDefinition,
+    NodeInvocation,
     PipelineDefinition,
     RepositoryDefinition,
-    SolidInvocation,
     TypeCheck,
     check,
     execute_pipeline,
     lambda_solid,
 )
-from dagster.core.definitions.logger import LoggerDefinition
+from dagster.core.definitions.logger_definition import LoggerDefinition
 from dagster.core.definitions.pipeline_base import InMemoryPipeline
-from dagster.core.definitions.resource import ScopedResourcesBuilder
-from dagster.core.definitions.solid import NodeDefinition
+from dagster.core.definitions.resource_definition import ScopedResourcesBuilder
+from dagster.core.definitions.solid_definition import NodeDefinition
 from dagster.core.execution.api import create_execution_plan, scoped_pipeline_context
+from dagster.core.execution.context.system import PlanExecutionContext
 from dagster.core.execution.context_creation_pipeline import (
-    SystemPipelineExecutionContext,
-    construct_execution_context_data,
     create_context_creation_data,
+    create_execution_data,
     create_executor,
     create_log_manager,
+    create_plan_data,
 )
 from dagster.core.instance import DagsterInstance
 from dagster.core.scheduler import Scheduler
@@ -55,8 +56,6 @@ from ..typing_api import is_typing_type
 
 
 def create_test_pipeline_execution_context(logger_defs=None):
-    from dagster.core.storage.intermediate_storage import build_in_mem_intermediates_storage
-
     loggers = check.opt_dict_param(
         logger_defs, "logger_defs", key_type=str, value_type=LoggerDefinition
     )
@@ -68,27 +67,26 @@ def create_test_pipeline_execution_context(logger_defs=None):
     pipeline_run = PipelineRun(pipeline_name="test_legacy_context", run_config=run_config)
     instance = DagsterInstance.ephemeral()
     execution_plan = create_execution_plan(pipeline=pipeline_def, run_config=run_config)
-    creation_data = create_context_creation_data(execution_plan, run_config, pipeline_run, instance)
+    creation_data = create_context_creation_data(
+        InMemoryPipeline(pipeline_def), execution_plan, run_config, pipeline_run, instance
+    )
     log_manager = create_log_manager(creation_data)
     scoped_resources_builder = ScopedResourcesBuilder()
     executor = create_executor(creation_data)
 
-    return SystemPipelineExecutionContext(
-        construct_execution_context_data(
+    return PlanExecutionContext(
+        plan_data=create_plan_data(creation_data, True, executor.retries),
+        execution_data=create_execution_data(
             context_creation_data=creation_data,
             scoped_resources_builder=scoped_resources_builder,
-            intermediate_storage=build_in_mem_intermediates_storage(pipeline_run.run_id),
-            log_manager=log_manager,
-            retry_mode=executor.retries,
-            raise_on_error=True,
         ),
-        executor=executor,
         log_manager=log_manager,
+        output_capture=None,
     )
 
 
 def _dep_key_of(solid):
-    return SolidInvocation(solid.definition.name, solid.name)
+    return NodeInvocation(solid.definition.name, solid.name)
 
 
 def build_pipeline_with_input_stubs(pipeline_def, inputs):
@@ -150,7 +148,7 @@ def execute_solids_within_pipeline(
         inputs (Optional[Dict[str, Dict[str, Any]]]): A dict keyed on solid names, whose values are
             dicts of input names to input values, used to pass input values to the solids directly.
             You may also use the ``run_config`` to configure any inputs that are configurable.
-        run_config (Optional[dict]): The environment configuration that parameterized this
+        run_config (Optional[dict]): The configuration that parameterized this
             execution, as a dict.
         mode (Optional[str]): The name of the pipeline mode to use. You may not set both ``mode``
             and ``preset``.
@@ -203,7 +201,7 @@ def execute_solid_within_pipeline(
         inputs (Optional[Dict[str, Any]]): A dict of input names to input values, used to
             pass input values to the solid directly. You may also use the ``run_config`` to
             configure any inputs that are configurable.
-        run_config (Optional[dict]): The environment configuration that parameterized this
+        run_config (Optional[dict]): The configuration that parameterized this
             execution, as a dict.
         mode (Optional[str]): The name of the pipeline mode to use. You may not set both ``mode``
             and ``preset``.
@@ -258,7 +256,7 @@ def yield_empty_pipeline_context(run_id=None, instance=None):
         ),
         parent_pipeline_snapshot=pipeline_def.get_parent_pipeline_snapshot(),
     )
-    with scoped_pipeline_context(execution_plan, {}, pipeline_run, instance) as context:
+    with scoped_pipeline_context(execution_plan, pipeline, {}, pipeline_run, instance) as context:
         yield context
 
 
@@ -284,7 +282,7 @@ def execute_solid(
             configure any inputs that are configurable.
         tags (Optional[Dict[str, Any]]): Arbitrary key-value pairs that will be added to pipeline
             logs.
-        run_config (Optional[dict]): The environment configuration that parameterized this
+        run_config (Optional[dict]): The configuration that parameterized this
             execution, as a dict.
         raise_on_error (Optional[bool]): Whether or not to raise exceptions when they occur.
             Defaults to ``True``, since this is the most useful behavior in test.
@@ -407,15 +405,6 @@ class FilesystemTestScheduler(Scheduler, ConfigurableClass):
     def debug_info(self):
         return ""
 
-    def start_schedule(self, instance, external_schedule):
-        pass
-
-    def stop_schedule(self, instance, schedule_origin_id):
-        pass
-
-    def running_schedule_count(self, instance, schedule_origin_id):
-        return 0
-
     def get_logs_path(self, _instance, schedule_origin_id):
         check.str_param(schedule_origin_id, "schedule_origin_id")
         return os.path.join(self._artifacts_dir, "logs", schedule_origin_id, "scheduler.log")
