@@ -1,15 +1,55 @@
 import os
 import subprocess
+import tempfile
 import warnings
 from contextlib import contextmanager
 
 import pytest
 
-from dagster import check
+from dagster import check, file_relative_path
+from dagster.core.test_utils import instance_for_test
+from dagster.utils import merge_dicts
 
 BUILDKITE = bool(os.getenv("BUILDKITE"))
 
 
+@contextmanager
+def postgres_instance_for_test(dunder_file, container_name, overrides=None, conn_args=None):
+    with tempfile.TemporaryDirectory() as temp_dir:
+        with TestPostgresInstance.docker_service_up_or_skip(
+            file_relative_path(dunder_file, "docker-compose.yml"),
+            container_name,
+            conn_args=conn_args,
+        ) as pg_conn_string:
+            TestPostgresInstance.clean_run_storage(pg_conn_string)
+            TestPostgresInstance.clean_event_log_storage(pg_conn_string)
+            TestPostgresInstance.clean_schedule_storage(pg_conn_string)
+            with instance_for_test(
+                temp_dir=temp_dir,
+                overrides=merge_dicts(
+                    {
+                        "run_storage": {
+                            "module": "dagster_postgres.run_storage.run_storage",
+                            "class": "PostgresRunStorage",
+                            "config": {"postgres_url": pg_conn_string},
+                        },
+                        "event_log_storage": {
+                            "module": "dagster_postgres.event_log.event_log",
+                            "class": "PostgresEventLogStorage",
+                            "config": {"postgres_url": pg_conn_string},
+                        },
+                        "schedule_storage": {
+                            "module": "dagster_postgres.schedule_storage.schedule_storage",
+                            "class": "PostgresScheduleStorage",
+                            "config": {"postgres_url": pg_conn_string},
+                        },
+                    },
+                    overrides if overrides else {},
+                ),
+            ) as instance:
+                yield instance
+
+
 class TestPostgresInstance:
     @staticmethod
     def dagster_postgres_installed():
@@ -23,10 +63,10 @@ class TestPostgresInstance:
     def get_hostname(env_name="POSTGRES_TEST_DB_HOST"):
         # In buildkite we get the ip address from this variable (see buildkite code for commentary)
         # Otherwise assume local development and assume localhost
-        return os.environ.get(env_name, "localhost")
+        return os.getenv(env_name, "localhost")
 
     @staticmethod
-    def conn_string(**kwargs):
+    def conn_string(env_name="POSTGRES_TEST_DB_HOST", **kwargs):
         check.invariant(
             TestPostgresInstance.dagster_postgres_installed(),
             "dagster_postgres must be installed to test with postgres",
@@ -38,27 +78,29 @@ class TestPostgresInstance:
                 dict(
                     username="test",
                     password="test",
-                    hostname=TestPostgresInstance.get_hostname(),
+                    hostname=TestPostgresInstance.get_hostname(env_name=env_name),
                     db_name="test",
                 ),
-                **kwargs
+                **kwargs,
             )
         )
 
     @staticmethod
-    def clean_run_storage(conn_string):
+    def clean_run_storage(conn_string, should_autocreate_tables=True):
         check.invariant(
             TestPostgresInstance.dagster_postgres_installed(),
             "dagster_postgres must be installed to test with postgres",
         )
         from dagster_postgres.run_storage import PostgresRunStorage  # pylint: disable=import-error
 
-        storage = PostgresRunStorage.create_clean_storage(conn_string)
+        storage = PostgresRunStorage.create_clean_storage(
+            conn_string, should_autocreate_tables=should_autocreate_tables
+        )
         assert storage
         return storage
 
     @staticmethod
-    def clean_event_log_storage(conn_string):
+    def clean_event_log_storage(conn_string, should_autocreate_tables=True):
         check.invariant(
             TestPostgresInstance.dagster_postgres_installed(),
             "dagster_postgres must be installed to test with postgres",
@@ -67,12 +109,14 @@ class TestPostgresInstance:
             PostgresEventLogStorage,
         )
 
-        storage = PostgresEventLogStorage.create_clean_storage(conn_string)
+        storage = PostgresEventLogStorage.create_clean_storage(
+            conn_string, should_autocreate_tables=should_autocreate_tables
+        )
         assert storage
         return storage
 
     @staticmethod
-    def clean_schedule_storage(conn_string):
+    def clean_schedule_storage(conn_string, should_autocreate_tables=True):
         check.invariant(
             TestPostgresInstance.dagster_postgres_installed(),
             "dagster_postgres must be installed to test with postgres",
@@ -81,13 +125,17 @@ class TestPostgresInstance:
             PostgresScheduleStorage,
         )
 
-        storage = PostgresScheduleStorage.create_clean_storage(conn_string)
+        storage = PostgresScheduleStorage.create_clean_storage(
+            conn_string, should_autocreate_tables=should_autocreate_tables
+        )
         assert storage
         return storage
 
     @staticmethod
     @contextmanager
-    def docker_service_up(docker_compose_file, service_name, conn_args=None):
+    def docker_service_up(
+        docker_compose_file, service_name, conn_args=None, env_name="POSTGRES_TEST_DB_HOST"
+    ):
         check.invariant(
             TestPostgresInstance.dagster_postgres_installed(),
             "dagster_postgres must be installed to test with postgres",
@@ -103,43 +151,55 @@ class TestPostgresInstance:
 
         if BUILDKITE:
             yield TestPostgresInstance.conn_string(
-                **conn_args
+                **conn_args,
+                env_name=env_name,
             )  # buildkite docker is handled in pipeline setup
             return
 
-        if not is_postgres_running(service_name):
-            try:
-                subprocess.check_output(
-                    ["docker-compose", "-f", docker_compose_file, "stop", service_name]
-                )
-                subprocess.check_output(
-                    ["docker-compose", "-f", docker_compose_file, "rm", "-f", service_name]
-                )
-            except subprocess.CalledProcessError:
-                pass
+        try:
+            subprocess.check_output(
+                ["docker-compose", "-f", docker_compose_file, "stop", service_name]
+            )
+            subprocess.check_output(
+                ["docker-compose", "-f", docker_compose_file, "rm", "-f", service_name]
+            )
+        except subprocess.CalledProcessError:
+            pass
 
-            try:
-                subprocess.check_output(
-                    ["docker-compose", "-f", docker_compose_file, "up", "-d", service_name],
-                    stderr=subprocess.STDOUT,  # capture STDERR for error handling
-                )
-            except subprocess.CalledProcessError as ex:
-                err_text = ex.output.decode()
-                raise PostgresDockerError(
-                    "Failed to launch docker container(s) via docker-compose: {}".format(err_text),
-                    ex,
-                )
+        try:
+            subprocess.check_output(
+                ["docker-compose", "-f", docker_compose_file, "up", "-d", service_name],
+                stderr=subprocess.STDOUT,  # capture STDERR for error handling
+            )
+        except subprocess.CalledProcessError as ex:
+            err_text = ex.output.decode("utf-8")
+            raise PostgresDockerError(
+                "Failed to launch docker container(s) via docker-compose: {}".format(err_text),
+                ex,
+            ) from ex
 
         conn_str = TestPostgresInstance.conn_string(**conn_args)
-        wait_for_connection(conn_str)
+        wait_for_connection(conn_str, retry_limit=10, retry_wait=3)
         yield conn_str
 
+        try:
+            subprocess.check_output(
+                ["docker-compose", "-f", docker_compose_file, "stop", service_name]
+            )
+            subprocess.check_output(
+                ["docker-compose", "-f", docker_compose_file, "rm", "-f", service_name]
+            )
+        except subprocess.CalledProcessError:
+            pass
+
     @staticmethod
     @contextmanager
-    def docker_service_up_or_skip(docker_compose_file, service_name, conn_args=None):
+    def docker_service_up_or_skip(
+        docker_compose_file, service_name, conn_args=None, env_name="POSTGRES_TEST_DB_HOST"
+    ):
         try:
             with TestPostgresInstance.docker_service_up(
-                docker_compose_file, service_name, conn_args
+                docker_compose_file, service_name, conn_args, env_name
             ) as conn_str:
                 yield conn_str
         except PostgresDockerError as ex:
@@ -165,15 +225,15 @@ def is_postgres_running(service_name):
             stderr=subprocess.STDOUT,  # capture STDERR for error handling
         )
     except subprocess.CalledProcessError as ex:
-        lines = ex.output.decode().split("\n")
+        lines = ex.output.decode("utf-8").split("\n")
         if len(lines) == 2 and "Cannot connect to the Docker daemon" in lines[0]:
-            raise PostgresDockerError("Cannot connect to the Docker daemon", ex)
+            raise PostgresDockerError("Cannot connect to the Docker daemon", ex) from ex
         else:
             raise PostgresDockerError(
                 "Could not verify postgres container was running as expected", ex
-            )
+            ) from ex
 
-    decoded = output.decode()
+    decoded = output.decode("utf-8")
     lines = decoded.split("\n")
 
     # header, one line for container, trailing \n
